@@ -19,3 +19,8 @@ pub use app::*;
 pub mod asynchronous;
 #[cfg(feature = "async")]
 pub use asynchronous::*;
+
+#[cfg(any(feature = "app", feature = "async"))]
+pub mod async_app;
+#[cfg(any(feature = "app", feature = "async"))]
+pub use async_app::*;
